==> pmml-model-1.0.0-sources.jar: org/dmg/pmml/NeuralOutput.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}DerivedField"/>
 *       &lt;/sequence>
 *       &lt;attribute name="outputNeuron" use="required" type="{http://www.dmg.org/PMML-4_1}NN-NEURON-IDREF" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "derivedField"
})
@XmlRootElement(name = "NeuralOutput")
public class NeuralOutput
    extends PMMLObject
    implements Equals, HashCode
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlElement(name = "DerivedField", required = true)
    protected DerivedField derivedField;
    @XmlAttribute(name = "outputNeuron", required = true)
    protected String outputNeuron;

    @Deprecated
    public NeuralOutput() {
        super();
    }

    public NeuralOutput(final DerivedField derivedField, final String outputNeuron) {
        super();
        this.derivedField = derivedField;
        this.outputNeuron = outputNeuron;
    }

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the derivedField property.
     * 
     * @return
     *     possible object is
     *     {@link DerivedField }
     *     
     */
    public DerivedField getDerivedField() {
        return derivedField;
    }

    /**
     * Sets the value of the derivedField property.
     * 
     * @param value
     *     allowed object is
     *     {@link DerivedField }
     *     
     */
    public void setDerivedField(DerivedField value) {
        this.derivedField = value;
    }

    /**
     * Gets the value of the outputNeuron property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOutputNeuron() {
        return outputNeuron;
    }

    /**
     * Sets the value of the outputNeuron property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOutputNeuron(String value) {
        this.outputNeuron = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof NeuralOutput)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final NeuralOutput that = ((NeuralOutput) object);
        {
            List<Extension> lhsExtensions;
            lhsExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            List<Extension> rhsExtensions;
            rhsExtensions = (((that.extensions!= null)&&(!that.extensions.isEmpty()))?that.getExtensions():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "extensions", lhsExtensions), LocatorUtils.property(thatLocator, "extensions", rhsExtensions), lhsExtensions, rhsExtensions)) {
                return false;
            }
        }
        {
            DerivedField lhsDerivedField;
            lhsDerivedField = this.getDerivedField();
            DerivedField rhsDerivedField;
            rhsDerivedField = that.getDerivedField();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "derivedField", lhsDerivedField), LocatorUtils.property(thatLocator, "derivedField", rhsDerivedField), lhsDerivedField, rhsDerivedField)) {
                return false;
            }
        }
        {
            String lhsOutputNeuron;
            lhsOutputNeuron = this.getOutputNeuron();
            String rhsOutputNeuron;
            rhsOutputNeuron = that.getOutputNeuron();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "outputNeuron", lhsOutputNeuron), LocatorUtils.property(thatLocator, "outputNeuron", rhsOutputNeuron), lhsOutputNeuron, rhsOutputNeuron)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "extensions", theExtensions), currentHashCode, theExtensions);
        }
        {
            DerivedField theDerivedField;
            theDerivedField = this.getDerivedField();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "derivedField", theDerivedField), currentHashCode, theDerivedField);
        }
        {
            String theOutputNeuron;
            theOutputNeuron = this.getOutputNeuron();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "outputNeuron", theOutputNeuron), currentHashCode, theOutputNeuron);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

}

==> pmml-model-1.0.3-sources.jar: org/dmg/pmml/NeuralOutput.java <==

package org.dmg.pmml;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}DerivedField"/>
 *       &lt;/sequence>
 *       &lt;attribute name="outputNeuron" use="required" type="{http://www.dmg.org/PMML-4_1}NN-NEURON-IDREF" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions",
    "derivedField"
})
@XmlRootElement(name = "NeuralOutput")
public class NeuralOutput
    extends PMMLObject
    implements Equals, HashCode, ToString
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlElement(name = "DerivedField", required = true)
    protected DerivedField derivedField;
    @XmlAttribute(name = "outputNeuron", required = true)
    protected String outputNeuron;

    @Deprecated
    public NeuralOutput() {
        super();
    }

    public NeuralOutput(final DerivedField derivedField, final String outputNeuron) {
        super();
        this.derivedField = derivedField;
        this.outputNeuron = outputNeuron;
    }

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the derivedField property.
     * 
     * @return
     *     possible object is
     *     {@link DerivedField }
     *     
     */
    public DerivedField getDerivedField() {
        return derivedField;
    }

    /**
     * Sets the value of the derivedField property.
     * 
     * @param value
     *     allowed object is
     *     {@link DerivedField }
     *     
     */
    public void setDerivedField(DerivedField value) {
        this.derivedField = value;
    }

    /**
     * Gets the value of the outputNeuron property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getOutputNeuron() {
        return outputNeuron;
    }

    /**
     * Sets the value of the outputNeuron property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setOutputNeuron(String value) {
        this.outputNeuron = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof NeuralOutput)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final NeuralOutput that = ((NeuralOutput) object);
        {
            List<Extension> lhsExtensions;
            lhsExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            List<Extension> rhsExtensions;
            rhsExtensions = (((that.extensions!= null)&&(!that.extensions.isEmpty()))?that.getExtensions():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "extensions", lhsExtensions), LocatorUtils.property(thatLocator, "extensions", rhsExtensions), lhsExtensions, rhsExtensions)) {
                return false;
            }
        }
        {
            DerivedField lhsDerivedField;
            lhsDerivedField = this.getDerivedField();
            DerivedField rhsDerivedField;
            rhsDerivedField = that.getDerivedField();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "derivedField", lhsDerivedField), LocatorUtils.property(thatLocator, "derivedField", rhsDerivedField), lhsDerivedField, rhsDerivedField)) {
                return false;
            }
        }
        {
            String lhsOutputNeuron;
            lhsOutputNeuron = this.getOutputNeuron();
            String rhsOutputNeuron;
            rhsOutputNeuron = that.getOutputNeuron();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "outputNeuron", lhsOutputNeuron), LocatorUtils.property(thatLocator, "outputNeuron", rhsOutputNeuron), lhsOutputNeuron, rhsOutputNeuron)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "extensions", theExtensions), currentHashCode, theExtensions);
        }
        {
            DerivedField theDerivedField;
            theDerivedField = this.getDerivedField();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "derivedField", theDerivedField), currentHashCode, theDerivedField);
        }
        {
            String theOutputNeuron;
            theOutputNeuron = this.getOutputNeuron();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "outputNeuron", theOutputNeuron), currentHashCode, theOutputNeuron);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            strategy.appendField(locator, this, "extensions", buffer, theExtensions);
        }
        {
            DerivedField theDerivedField;
            theDerivedField = this.getDerivedField();
            strategy.appendField(locator, this, "derivedField", buffer, theDerivedField);
        }
        {
            String theOutputNeuron;
            theOutputNeuron = this.getOutputNeuron();
            strategy.appendField(locator, this, "outputNeuron", buffer, theOutputNeuron);
        }
        return buffer;
    }

}
